Module blaxel.core.client.models.preview_token_metadata
=======================================================

Classes
-------

`PreviewTokenMetadata(name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, preview_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, resource_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, resource_type: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, workspace: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   PreviewTokenMetadata
    
    Attributes:
        name (Union[Unset, str]): Token name
        preview_name (Union[Unset, str]): Preview name
        resource_name (Union[Unset, str]): Resource name
        resource_type (Union[Unset, str]): Resource type
        workspace (Union[Unset, str]): Workspace name
    
    Method generated by attrs for class PreviewTokenMetadata.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    `preview_name: blaxel.core.client.types.Unset | str`
    :

    `resource_name: blaxel.core.client.types.Unset | str`
    :

    `resource_type: blaxel.core.client.types.Unset | str`
    :

    `workspace: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :